@@ -38,7 +38,7 @@ import glance.db
 from glance import image_cache
 import glance.openstack.common.log as logging
 from glance import notifier
-from glance import registry
+import glance.registry.client.v1.api as registry
 
 LOG = logging.getLogger(__name__)
 
@@ -71,7 +71,7 @@ class CacheFilter(wsgi.Middleware):
         if not image_meta['size']:
             # override image size metadata with the actual cached
             # file size, see LP Bug #900959
-            image_meta['size'] = self.cache.get_image_size(image_id)
+            image_meta['size'] = self.cache.get_image_size(image_meta['id'])
 
     @staticmethod
     def _match_request(request):
@@ -133,7 +133,7 @@ class CacheFilter(wsgi.Middleware):
         except exception.NotFound:
             msg = _("Image cache contained image file for image '%s', "
                     "however the registry did not contain metadata for "
-                    "that image!" % image_id)
+                    "that image!") % image_id
             LOG.error(msg)
             self.cache.delete_cached_image(image_id)
 
@@ -164,6 +164,7 @@ class CacheFilter(wsgi.Middleware):
         # Don't display location
         if 'location' in image_meta:
             del image_meta['location']
+        image_meta.pop('location_data', None)
         self._verify_metadata(image_meta)
 
         response = webob.Response(request=request)
@@ -189,6 +190,18 @@ class CacheFilter(wsgi.Middleware):
                                               image_meta['size'],
                                               image_iterator,
                                               notifier.Notifier())
+        # NOTE (flwang): Set the content-type, content-md5 and content-length
+        # explicitly to be consistent with the non-cache scenario.
+        # Besides, it's not worth the candle to invoke the "download" method
+        # of ResponseSerializer under image_data. Because method "download"
+        # will reset the app_iter. Then we have to call method
+        # "size_checked_iter" to avoid missing any notification. But after
+        # call "size_checked_iter", we will lose the content-md5 and
+        # content-length got by the method "download" because of this issue:
+        # https://github.com/Pylons/webob/issues/86
+        response.headers['Content-Type'] = 'application/octet-stream'
+        response.headers['Content-MD5'] = image.checksum
+        response.headers['Content-Length'] = str(image.size)
         return response
 
     def process_response(self, resp):
