@@ -90,7 +90,7 @@ def swift_connect(auth_url, auth_version, user, key):
 def swift_list_containers(swift_conn):
     try:
         _, containers = swift_conn.get_account()
-    except Exception, e:
+    except Exception as e:
         msg = ("Failed to list containers (get_account) "
                "from Swift. Got error: %s" % e)
         raise SwiftStoreError(msg)
@@ -101,7 +101,7 @@ def swift_list_containers(swift_conn):
 def swift_create_container(swift_conn, container_name):
     try:
         swift_conn.put_container(container_name)
-    except swiftclient.ClientException, e:
+    except swiftclient.ClientException as e:
         msg = "Failed to create container. Got error: %s" % e
         raise SwiftStoreError(msg)
 
@@ -113,7 +113,7 @@ def swift_get_container(swift_conn, container_name, **kwargs):
 def swift_delete_container(swift_conn, container_name):
     try:
         swift_conn.delete_container(container_name)
-    except swiftclient.ClientException, e:
+    except swiftclient.ClientException as e:
         msg = "Failed to delete container from Swift. Got error: %s" % e
         raise SwiftStoreError(msg)
 
@@ -180,16 +180,6 @@ class TestSwiftStore(store_tests.BaseTestCase, testtools.TestCase):
         store.configure_add()
         return store
 
-    def get_default_store_specs(self, image_id):
-        return {
-            'scheme': 'swift+http',
-            'auth_or_store_url': self.swift_config['swift_store_auth_address'],
-            'user': self.swift_config['swift_store_user'],
-            'key': self.swift_config['swift_store_key'],
-            'container': self.swift_config['swift_store_container'],
-            'obj': image_id,
-        }
-
     def test_object_chunking(self):
         """Upload an image that is split into multiple swift objects.
 
@@ -206,9 +196,9 @@ class TestSwiftStore(store_tests.BaseTestCase, testtools.TestCase):
         image_size = 5242880  # 5 MB
         image_data = StringIO.StringIO('X' * image_size)
         image_checksum = 'eb7f8c3716b9f059cee7617a4ba9d0d3'
-        uri, add_size, add_checksum = store.add(image_id,
-                                                image_data,
-                                                image_size)
+        uri, add_size, add_checksum, _ = store.add(image_id,
+                                                   image_data,
+                                                   image_size)
 
         self.assertEqual(image_size, add_size)
         self.assertEqual(image_checksum, add_checksum)
@@ -345,7 +335,7 @@ class TestSwiftStore(store_tests.BaseTestCase, testtools.TestCase):
 
         image_id = uuidutils.generate_uuid()
         image_data = StringIO.StringIO('XXX')
-        uri, _, _ = store.add(image_id, image_data, 3)
+        uri, _, _, _ = store.add(image_id, image_data, 3)
 
         location = glance.store.location.Location(
                 self.store_name,
@@ -362,14 +352,16 @@ class TestSwiftStore(store_tests.BaseTestCase, testtools.TestCase):
 
         container_name = location.store_location.container
         container, _ = swift_get_container(self.swift_client, container_name)
-        self.assertEqual(read_tenant, container.get('x-container-read'))
-        self.assertEqual(write_tenant, container.get('x-container-write'))
+        self.assertEqual(read_tenant + ':*',
+                         container.get('x-container-read'))
+        self.assertEqual(write_tenant + ':*',
+                         container.get('x-container-write'))
 
         store.set_acls(location, public=True, read_tenants=[read_tenant])
 
         container_name = location.store_location.container
         container, _ = swift_get_container(self.swift_client, container_name)
-        self.assertEqual('.r:*', container.get('x-container-read'))
+        self.assertEqual('.r:*,.rlistings', container.get('x-container-read'))
         self.assertEqual('', container.get('x-container-write', ''))
 
         (get_iter, get_size) = store.get(location)
